@@ -1,4 +1,4 @@
-#!/usr/bin/env perl
+#!/usr/bin/perl
 #
 # Copyright (c) 2001 Tama Communications Corporation
 #
@@ -67,7 +67,7 @@ sub getvalue {
 	# A value should be defined as:
 	# NAME='VALUE'
 	#
-	my $line=`grep "^$name=" configure.ac`;
+	my $line=`grep "$name=" configure.ac`;
 	($value) = $line =~ /^$name='(.*)'$/;
 	unless ($value) {
 		print STDERR "$name not found.\n";
@@ -83,11 +83,11 @@ sub langmapstatement {
 	my(@statement);
 	my %name = (
 		'c'	=> 'C',
-		'yacc'	=> 'Yacc',
+		'yacc'	=> 'yacc',
+		'asm'	=> 'Assembly',
 		'java'	=> 'Java',
 		'cpp'	=> 'C++',
 		'php'	=> 'PHP',
-		'asm'	=> 'assembly language',
 	);
 	my $line = '';
 	my @maps = split(/,/, $maps);
@@ -103,7 +103,7 @@ sub langmapstatement {
 		}
 		$line .= $name{$lang};
 	}
-	$line .= " source files.\n";
+	$line .= " source files are supported.\n";
 	unshift(@statement, $line);
 	foreach (@maps) {
 		my($lang, $suffixes) = /([^:]+):(.*)/;
@@ -170,9 +170,6 @@ sub convert {
 	while (s/\@xref\{($arg),($arg)\}/$1($2)/) {
 		;
 	}
-	while (s/\@(begin|end)_verbatim//) {
-		;
-	}
 }
 sub gen {
 	local($help_const) = 0;
@@ -266,11 +263,9 @@ sub convert {
 	while (s/\@xref\{($arg),($arg)\}/\\fB$1\\fP($2)/) {
 		;
 	}
-	s/\@\{/\{/g;
-	s/\@\}/\}/g;
+	s/\@{/{/g;
+	s/\@}/}/g;
 	s/\@br$/\n.br/;
-	s/\@\@/@/g;
-	s/^\./\\&./;
 }
 sub gen {
 	local($arg) = '[^,]+';
@@ -396,7 +391,6 @@ sub gen {
 				} elsif ($verbatim) {
 					s/\{/@\{/g;
 					s/\}/@\}/g;
-					s/^\s+//;
 					print;
 					next;
 				} elsif (/^\@/) {
