@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2005, 2006,
- *	2007, 2008, 2010, 2011, 2012, 2013, 2014
+ *	2007, 2008, 2010, 2011, 2012, 2013, 2014, 2015
  *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
@@ -85,6 +85,7 @@ int iflag;				/* [option]		*/
 int Iflag;				/* command		*/
 int Lflag;				/* [option]		*/
 int Mflag;				/* [option]		*/
+int Nflag;				/* [option]		*/
 int nflag;				/* [option]		*/
 int oflag;				/* [option]		*/
 int Oflag;				/* [option]		*/
@@ -115,6 +116,7 @@ char use_color;				/**< coloring */
 const char *cwd;			/**< current directory	*/
 const char *root;			/**< root of source tree	*/
 const char *dbpath;			/**< dbpath directory	*/
+const char *nearbase;			/**< nearbase directory	*/
 char *context_file;
 char *context_lineno;
 char *file_list;
@@ -175,6 +177,7 @@ static struct option const long_options[] = {
 	{"file-list", required_argument, NULL, 'L'},
 	{"match-case", no_argument, NULL, 'M'},
 	{"nofilter", optional_argument, NULL, 'n'},
+	{"nearness", optional_argument, NULL, 'N'},
 	{"grep", no_argument, NULL, 'g'},
 	{"basic-regexp", no_argument, NULL, 'G'},
 	{"ignore-case", no_argument, NULL, 'i'},
@@ -391,7 +394,7 @@ main(int argc, char **argv)
 	openconf(root);
 	setenv_from_config();
 	logging_arguments(argc, argv);
-	while ((optchar = getopt_long(argc, argv, "acde:EifFgGIlL:MnoOpPqrsS:tTuvVx", long_options, &option_index)) != EOF) {
+	while ((optchar = getopt_long(argc, argv, "acde:EifFgGIlL:MnNoOpPqrsS:tTuvVx", long_options, &option_index)) != EOF) {
 		switch (optchar) {
 		case 0:
 			break;
@@ -455,6 +458,11 @@ main(int argc, char **argv)
 				nofilter = BOTH_FILTER;
 			}
 			break;
+		case 'N':
+			Nflag++;
+			if (optarg)
+				nearbase = optarg;
+			break;
 		case 'o':
 			oflag++;
 			break;
@@ -598,6 +606,12 @@ main(int argc, char **argv)
 		help();
 	if (dbpath == NULL)
 		die_with_code(-status, gtags_dbpath_error);
+	if (nearbase) {
+		if (!test("d", nearbase)) 
+			die("'%s' not found.", nearbase);
+		if (set_nearbase_path(nearbase) == NULL)
+			die("internal error: '%s'.", nearbase);
+	}
 	/*
 	 * decide format.
 	 * The --result option is given to priority more than the -t and -x option.
@@ -1213,7 +1227,9 @@ idutils(const char *pattern, const char *dbpath)
 		strbuf_puts(ib, " --result=grep");
 	if (iflag)
 		strbuf_puts(ib, " --ignore-case");
-	if (isregex(pattern))
+	if (literal)
+		strbuf_puts(ib, " --literal");
+	else if (isregex(pattern))
 		strbuf_puts(ib, " --regexp");
 	strbuf_putc(ib, ' ');
 	strbuf_puts(ib, quote_shell(pattern));
@@ -1435,7 +1451,10 @@ pathlist(const char *pattern, const char *dbpath)
 		/*
 		 * We assume '^aaa' as '^/aaa'.
 		 */
-		if (*pattern == '^' && *(pattern + 1) != '/') {
+		if (literal) {
+			strlimcpy(edit, quote_string(pattern), sizeof(edit));
+			pattern = edit;
+		} else if (*pattern == '^' && *(pattern + 1) != '/') {
 			snprintf(edit, sizeof(edit), "^/%s", pattern + 1);
 			pattern = edit;
 		}
@@ -1702,7 +1721,11 @@ search(const char *pattern, const char *root, const char *cwd, const char *dbpat
 	 */
 	if (nofilter & SORT_FILTER)
 		flags |= GTOP_NOSORT;
-	if (Gflag)
+	else if (Nflag)
+		flags |= GTOP_NEARSORT;
+	if (literal)
+		flags |= GTOP_NOREGEX;
+	else if (Gflag)
 		flags |= GTOP_BASICREGEX;
 	if (format == FORMAT_PATH)
 		flags |= GTOP_PATH;
@@ -1739,7 +1762,7 @@ tagsearch(const char *pattern, const char *cwd, const char *root, const char *db
 	/*
 	 * trim pattern (^<no regex>$ => <no regex>)
 	 */
-	if (pattern) {
+	if (!literal && pattern) {
 		strlimcpy(p, pattern, sizeof(buffer));
 		if (*p++ == '^') {
 			char *q = p + strlen(p);
