@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2008,
- *	2010
+ *	2010, 2015
  *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
@@ -302,10 +302,13 @@ C_family(const struct parser_param *param, int type)
 			if (c == SYMBOL) {
 				if (peekc(0) == '{') /* } */ {
 					PUT(PARSER_DEF, token, lineno, sp);
+					do {
+						c = nexttoken(interested, c_reserved_word);
+					} while (c == '\n');
 				} else {
 					PUT(PARSER_REF_SYM, token, lineno, sp);
+					c = nexttoken(interested, c_reserved_word);
 				}
-				c = nexttoken(interested, c_reserved_word);
 			}
 			if (c == '{' /* } */ && cc == C_ENUM) {
 				enumerator_list(param);
@@ -359,12 +362,14 @@ C_family(const struct parser_param *param, int type)
 					if (c == SYMBOL) {
 						if (peekc(0) == '{') /* } */ {
 							PUT(PARSER_DEF, token, lineno, sp);
+							do {
+								c = nexttoken(interest_enum, c_reserved_word);
+							} while (c == '\n');
 						} else {
 							PUT(PARSER_REF_SYM, token, lineno, sp);
+							c = nexttoken(interest_enum, c_reserved_word);
 						}
-						c = nexttoken(interest_enum, c_reserved_word);
 					}
-				
 					if (c_ == C_ENUM) {
 						if (c == '{') /* } */
 							c = enumerator_list(param);
