@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2008, 2009,
- *	2010
+ *	2010, 2015
  *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
@@ -208,9 +208,12 @@ Cpp(const struct parser_param *param)
 							c = nexttoken(NULL, cpp_reserved_word);
 							if (c == SYMBOL)
 								PUT(PARSER_REF_SYM, token, lineno, sp);
-							else if (c == '<')
-								++templates;
-							else if (c == '>') {
+							if (c == '<') {
+								if (peekc(1) == '<')
+									throwaway_nextchar();
+								else
+									++templates;
+							} else if (c == '>') {
 								if (--templates == 0)
 									break;
 							} else if (c == EOF)
@@ -347,10 +350,13 @@ Cpp(const struct parser_param *param)
 			if (c == SYMBOL) {
 				if (peekc(0) == '{') /* } */ {
 					PUT(PARSER_DEF, token, lineno, sp);
+					do {
+						c = nexttoken(interested, cpp_reserved_word);
+					} while (c == '\n');
 				} else {
 					PUT(PARSER_REF_SYM, token, lineno, sp);
+					c = nexttoken(interested, cpp_reserved_word);
 				}
-				c = nexttoken(interested, cpp_reserved_word);
 			}
 			if (c == '{' /* } */ && cc == CPP_ENUM) {
 				enumerator_list(param);
@@ -441,8 +447,12 @@ Cpp(const struct parser_param *param)
 					if (c == SYMBOL) {
 						if (peekc(0) == '{') /* } */ {
 							PUT(PARSER_DEF, token, lineno, sp);
+							do {
+								c = nexttoken(interest_enum, cpp_reserved_word);
+							} while (c == '\n');
 						} else {
 							PUT(PARSER_REF_SYM, token, lineno, sp);
+							c = nexttoken(interest_enum, cpp_reserved_word);
 						}
 						c = nexttoken(interest_enum, cpp_reserved_word);
 					}
