@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 1998, 1999, 2000, 2002, 2008, 2011, 2014
+ * Copyright (c) 1997, 1998, 1999, 2000, 2002, 2008, 2011, 2014, 2015
  *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
@@ -36,6 +36,7 @@
 #endif
 
 #include "gparam.h"
+#include "abs2rel.h"
 #include "die.h"
 #include "getdbpath.h"
 #include "gtagsop.h"
@@ -191,6 +192,8 @@ static char dbpath[MAXPATHLEN];
 static char root[MAXPATHLEN];
 static char root_with_slash[MAXPATHLEN];
 static char cwd[MAXPATHLEN];
+static char nearbase[MAXPATHLEN];
+static char relative_cwd_with_slash[MAXPATHLEN+2];
 /**
  * setupdbpath: setup dbpath directory
  *
@@ -332,6 +335,11 @@ ignore_lab:;
 		strlimcpy(root_with_slash, root, sizeof(root_with_slash));
 	else
 		snprintf(root_with_slash, sizeof(root_with_slash), "%s/", root);
+	/*
+	 * relative from the project root directory.
+	 */
+	snprintf(relative_cwd_with_slash,
+		sizeof(relative_cwd_with_slash), "./%s/", cwd + strlen(root) + 1);
 	return 0;
 }
 /**
@@ -374,11 +382,35 @@ get_cwd(void)
 {
 	return (const char *)cwd;
 }
+const char *
+get_relative_cwd_with_slash(void)
+{
+	return (const char *)relative_cwd_with_slash;
+}
+const char *
+set_nearbase_path(const char *path)
+{
+	char norm[MAXPATHLEN], real[MAXPATHLEN];
+
+	if (normalize_pathname(path, norm, sizeof(norm)) == NULL)
+		return NULL;
+	path = norm;
+	if (root[0] == '\0' || realpath(path, real) == NULL)
+		return NULL;
+	snprintf(nearbase, sizeof(nearbase), "./%s/", real + strlen(root) + 1);
+	return nearbase;
+}
+const char *
+get_nearbase_path(void)
+{
+	return nearbase[0] ? (const char *)nearbase : NULL;
+}
 void
 dump_dbpath(void)
 {
 	fprintf(stderr, "db path: %s\n", dbpath);
 	fprintf(stderr, "root path: %s\n", root);
 	fprintf(stderr, "current directory: %s\n", cwd);
+	fprintf(stderr, "nearbase: %s\n", nearbase);
 }
 /** @} */
